@@ -1,8 +1,11 @@
 use std::{convert::TryInto, fs::File};
 
 use tabled::{Style, Table, Tabled};
-use vach2::prelude::{HeaderConfig, Archive, Flags};
-use bytesize::ByteSize;
+use vach::{
+	prelude::{HeaderConfig, Archive, Flags},
+	archive::CompressionAlgorithm,
+};
+use indicatif::HumanBytes;
 
 use super::CommandTrait;
 use crate::keys::key_names;
@@ -18,32 +21,50 @@ impl CommandTrait for Evaluator {
 			Some(path) => path,
 			None => {
 				anyhow::bail!("Please provide an input archive file using the -i or --input keys!")
-			}
+			},
 		};
 
-		let magic: [u8; vach2::MAGIC_LENGTH] = match args.value_of(key_names::MAGIC) {
+		let magic: [u8; vach::MAGIC_LENGTH] = match args.value_of(key_names::MAGIC) {
 			Some(magic) => magic.as_bytes().try_into()?,
-			None => *vach2::DEFAULT_MAGIC,
+			None => *vach::DEFAULT_MAGIC,
 		};
 
 		let file = File::open(archive_path)?;
 		let archive = Archive::with_config(file, &HeaderConfig::new(magic, None))?;
 
-		if !archive.entries().is_empty() {
+		if archive.entries().is_empty() {
+			println!("<EMPTY ARCHIVE> @ {}", archive_path);
+		} else {
 			let table_entries: Vec<FileTableEntry> = archive
 				.entries()
 				.iter()
-				.map(|(id, entry)| FileTableEntry {
-					id,
-					size: ByteSize(entry.offset).to_string(),
-					flags: entry.flags,
+				.map(|(id, entry)| {
+					let c_algo = if entry.flags.contains(Flags::LZ4_COMPRESSED) {
+						Some(CompressionAlgorithm::LZ4)
+					} else if entry.flags.contains(Flags::BROTLI_COMPRESSED) {
+						Some(CompressionAlgorithm::Brotli(8))
+					} else if entry.flags.contains(Flags::SNAPPY_COMPRESSED) {
+						Some(CompressionAlgorithm::Snappy)
+					} else {
+						None
+					};
+
+					let c_algo = match c_algo {
+						Some(algo) => algo.to_string(),
+						None => "None".to_string(),
+					};
+
+					FileTableEntry {
+						id,
+						size: HumanBytes(entry.offset).to_string(),
+						flags: entry.flags,
+						compression: c_algo,
+					}
 				})
 				.collect();
 
 			let table = Table::new(table_entries).with(Style::PSEUDO_CLEAN);
-			println!("{}", table.to_string());
-		} else {
-			println!("<EMPTY ARCHIVE> @ {}", archive_path);
+			println!("{}", table);
 		}
 
 		Ok(())
@@ -55,4 +76,5 @@ struct FileTableEntry<'a> {
 	id: &'a str,
 	size: String,
 	flags: Flags,
+	compression: String,
 }
