@@ -4,7 +4,7 @@ use clap::ArgMatches;
 use anyhow::Result;
 
 // A common progress bar style for all commands
-const PROGRESS_BAR_STYLE: &str = "{wide_bar} {pos:>7}/{len:7} ETA {eta_precise}";
+const PROGRESS_BAR_STYLE: &str = "[{elapsed_precise}] {spinner} {bar:80.cyan/blue} {pos:>7}/{len:7} {msg}";
 
 // Trait that must be implemented by all subcommands
 pub trait CommandTrait: Sync {
@@ -30,4 +30,4 @@ pub fn build_commands() -> HashMap<&'static str, Box<dyn CommandTrait>> {
 	map.insert("pack", Box::new(pack::Evaluator));
 
 	map
-}
\ No newline at end of file
+}
