@@ -4,7 +4,6 @@ use std::collections::HashMap;
 pub mod key_names {
 	pub(crate) const OUTPUT: &str = "OUTPUT";
 	pub(crate) const INPUT: &str = "INPUT";
-	pub(crate) const SOURCE: &str = "SOURCE";
 
 	pub(crate) const DIR_INPUT: &str = "DIR_INPUT";
 	pub(crate) const DIR_INPUT_REC: &str = "DIR_INPUT_REC";
@@ -16,6 +15,7 @@ pub mod key_names {
 	pub(crate) const VERSION: &str = "VERSION";
 	pub(crate) const MAGIC: &str = "MAGIC";
 	pub(crate) const COMPRESS_MODE: &str = "COMPRESS_MODE";
+	pub(crate) const COMPRESS_ALGO: &str = "COMPRESS_ALGO";
 	pub(crate) const HASH: &str = "HASH";
 	pub(crate) const ENCRYPT: &str = "ENCRYPT";
 	pub(crate) const SPLIT_KEY: &str = "SPLIT_KEY";
@@ -109,19 +109,6 @@ pub fn build_keys<'a>() -> HashMap<&'static str, Arg<'a>> {
 			.takes_value(false),
 	);
 
-	// treats the entries in a .vach file like regular files, but with metadata from the archive
-	map.insert(
-		key_names::SOURCE,
-		Arg::new(key_names::SOURCE)
-			.long("source")
-			.short('z')
-			.value_name(key_names::SOURCE)
-			.help("Treats the entries in a .vach file like regular files and adds them to the input queue")
-			.required(false)
-			.takes_value(false)
-			.number_of_values(1),
-	);
-
 	// treats the entries in a .vach file like regular files, but with metadata from the archive
 	map.insert(
 		key_names::MAGIC,
@@ -134,10 +121,10 @@ pub fn build_keys<'a>() -> HashMap<&'static str, Arg<'a>> {
 			.takes_value(true)
 			.number_of_values(1)
 			.validator(|magic| {
-				if magic.len() != vach2::MAGIC_LENGTH {
+				if magic.len() != vach::MAGIC_LENGTH {
 					return Err(format!(
 						"Please provide a magic of the right length: {}. Magic: {} has length: {}",
-						vach2::MAGIC_LENGTH,
+						vach::MAGIC_LENGTH,
 						&magic,
 						magic.len()
 					));
@@ -159,6 +146,7 @@ pub fn build_keys<'a>() -> HashMap<&'static str, Arg<'a>> {
 			.takes_value(true)
 			.number_of_values(1)
 			.validator(|c_mode| {
+				let c_mode = c_mode.to_ascii_lowercase();
 				if c_mode != "always" && c_mode != "never" && c_mode != "detect" {
 					return Err(format!("Please provide a valid Compress Mode, either 'Always', 'Detect' or 'Never' (case insensitive). Not: {}", c_mode));
 				};
@@ -167,6 +155,27 @@ pub fn build_keys<'a>() -> HashMap<&'static str, Arg<'a>> {
 			}),
 	);
 
+	// The compression algorithm to use for the adjacent leafs
+	map.insert(
+		key_names::COMPRESS_ALGO,
+		Arg::new(key_names::COMPRESS_ALGO)
+			.long("compress-algo")
+			.short('g')
+			.value_name(key_names::COMPRESS_ALGO)
+			.help("The compression algorithm to use in compression, can be; 'lz4', 'brotli' or 'snappy'")
+			.required(false)
+			.takes_value(true)
+			.number_of_values(1)
+			.validator(|c_mode| {
+				let c_mode = c_mode.to_ascii_lowercase();
+				if c_mode != "lz4" && c_mode != "brotli" && c_mode != "snappy" {
+					return Err(format!("Please provide a valid Compression Algorithm to use, either 'lz4', 'brotli' or 'snappy' (case insensitive). Not: {}", c_mode));
+				};
+
+				Ok(())
+			}),
+	);
+
 	// To sign the entries and include the signatures in the target, an sk or kp must be provided
 	map.insert(
 		key_names::HASH,
@@ -280,7 +289,5 @@ pub fn build_keys<'a>() -> HashMap<&'static str, Arg<'a>> {
 			.number_of_values(1),
 	);
 
-	assert_eq!(map.len(), 18);
-
 	map
 }
